local name, addon = ...
local parentName = addon['parentName'] or "BrokerPack"
local childName = "zz_Infoclock"

local defaults = {
	["showClock"] = true,
	["showLatency"] = true,
	["showFPS"] = true,
}
local options = {
}
local ldb = LibStub:GetLibrary("LibDataBroker-1.1")
local ldbicon = LibStub("LibDBIcon-1.0")
local L = LibStub("AceLocale-3.0"):GetLocale(childName, true)
local line

local nextUpdate = GetTime()
local db = {}

local function toggleColor(col,col1,col2)
	return col == col1 and col2 or col1
end

local function OnTooltip()
	GameTooltip:ClearLines()
	GameTooltip:AddLine(childName)
	local col = toggleColor(col,"ffffff","00ff00")
	GameTooltip:AddLine(addon['colorize'](format("%s, %s.%s",L[date("%A")],date("%d"),L[date("%B")]),col))
	col = toggleColor(col,"ffffff","00ff00")
	if(db["12-Hours"]) then
		GameTooltip:AddDoubleLine(addon['colorize'](L['Time'],col),addon['colorize'](date("%I:%M:%S"),toggleColor(col,"ffffff","00ff00")))
	else
		GameTooltip:AddDoubleLine(addon['colorize'](L['Time'],col),addon['colorize'](date("%H:%M:%S"),toggleColor(col,"ffffff","00ff00")))
	end
	col = toggleColor(col,"ffffff","00ff00")
	GameTooltip:AddDoubleLine(addon['colorize'](L['Latency'],col),addon['colorize'](format("%s ms",select(3,GetNetStats())),toggleColor(col,"ffffff","00ff00")))
	col = toggleColor(col,"ffffff","00ff00")
	GameTooltip:AddDoubleLine(addon['colorize'](L['FPS'],col),addon['colorize'](format("%i fps",floor(GetFramerate())),toggleColor(col,"ffffff","00ff00")))
	col = toggleColor(col,"ffffff","00ff00")
	GameTooltip:AddDoubleLine(addon['colorize'](L['AddOn Memory'],col),addon['colorize'](format("%i MB",floor(collectgarbage('count')/1024)),toggleColor(col,"ffffff","00ff00")))
	GameTooltip:AddLine(" ")
	GameTooltip:AddLine(L['HINT4'])
	GameTooltip:AddLine(L["garbagecollect"])
	GameTooltip:AddLine(L['HINT3'])
end

local function OnText(message)
	addon['OnText'](childName, message)
end

local function OnButton(self, button)
	if(button == 'RightButton') then
		InterfaceOptionsFrame_OpenToCategory(childName)
	else
		if(IsShiftKeyDown()) then
			local db = addon['db']['global']['ldbicons']
			db[childName]['hide'] = not db[childName]['hide']
			if(ldbicon) then
				if(db[childName]['hide']) then
					ldbicon:Hide(childName)
				else
					ldbicon:Show(childName)
				end
			end
		elseif(IsControlKeyDown()) then
			addon['Print'](L["garbagecollected"])
			collectgarbage("collect")
		else
			GameTimeFrame_OnClick(_G["GameTimeFrame"])
		end
	end
end

local function OnDataUpdate(self)
	if(nextUpdate > GetTime()) then return end
	nextUpdate = GetTime() + 1
	line = ''
	if(db["showClock"]) then
		line = format("%s%s ", line, db["12-Hours"] and date("%I:%M") or date("%H:%M"))
	end
	if(db["showLatency"]) then
		line = format("%s%s",line,addon['colorize'](format("%s ms ",select(3,GetNetStats())),"ffff00"))
	end
	if(db["showFPS"]) then
		line = format("%s%s fps", line, floor(GetFramerate()))
	end  
	if(line ~= '') then
		OnText(line)
	else
		OnText(childName)
	end
	if(GameTooltip:GetOwner() and GameTooltip:GetOwner():GetName() and GameTooltip:GetOwner():GetName():sub(childName:len() * -1) == childName) then
		OnTooltip()
	end
end

local function getPref(pref)
	return db[pref[#pref]]
end

local function setPref(pref,value)
	db[pref[#pref]] = value
end

local function init()
	options = addon['InitConfig'](addon, childName, true, {
		['name'] = childName,
		['type'] = "data source",
		['OnTooltipShow'] = OnTooltip,
		['OnClick'] = OnButton,
	}, getPref, setPref)
	db = addon['db']['profile'][childName]
	addon['AddConfigEntry'](addon,childName,"toggle","showClock",L['Show Clock'],nil,2,nil,nil,nil,nil,options)
	addon['AddConfigEntry'](addon,childName,"toggle","showLatency",L['Show Latency'],nil,3,nil,nil,nil,nil,options)
	addon['AddConfigEntry'](addon,childName,"toggle","showFPS",L['Show FPS'],nil,4,nil,nil,nil,nil,options)
	addon['AddConfigEntry'](addon,childName,"toggle","12-Hours",L['12-Hours'],nil,5,nil,nil,nil,nil,options)
	addon['RegisterFunc'](nil,"OnUpdate", OnDataUpdate)
end

addon['startup'](addon, name, childName, init, true, defaults)
